==> haskell-tagstream-conduit-0.5.6-461-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-Av2pQG3deziEkXwLYF1SCZ
key:                  tagstream-conduit-0.5.6-Av2pQG3deziEkXwLYF1SCZ
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  cf8d66ddea0e3919f0d7cefd93011960
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagstream-conduit
hs-libraries:         HStagstream-conduit-0.5.6-Av2pQG3deziEkXwLYF1SCZ
depends:
    attoparsec-0.14.4-2y9eL1gxaFn1uCSGoZSkZz base-4.17.2.1
    blaze-builder-0.4.3-7r9do9coum54RrdacWKvDM bytestring-0.11.5.3
    case-insensitive-1.2.1.0-7gqgHDj4ifWAUMF7u0wWwn
    conduit-1.3.6.1-D5gtRvoNCm9CE8oOCirzgp
    conduit-extra-1.3.8-Jri1WWy2jtULQf90nsZCJV
    data-default-0.7.1.1-7mS5xpY4EnxodGGT6vPB1
    resourcet-1.2.6-HE3LPlgg2aD9KCPumUFvOx text-2.0.2
    transformers-0.5.6.2 xml-conduit-1.9.1.4-3iMsbkaVWdj82Er1gxwGTR

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagstream-conduit-0.5.6-463-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-LQZpSrHnXkXDzzN1K0Jzjn
key:                  tagstream-conduit-0.5.6-LQZpSrHnXkXDzzN1K0Jzjn
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  ef5d89b5b70b8b2b287d2ed9c41a4443
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagstream-conduit
hs-libraries:         HStagstream-conduit-0.5.6-LQZpSrHnXkXDzzN1K0Jzjn
depends:
    attoparsec-0.14.4-62hSVPdjEK0BKtGrIEp0w5 base-4.17.2.1
    blaze-builder-0.4.3-28SzfArXjkvErNNh4sXQKm bytestring-0.11.5.3
    case-insensitive-1.2.1.0-D4Bx6jK2099tFJcppXDxv
    conduit-1.3.6.1-FVLYIXkx9NyFPBDwnE2wvC
    conduit-extra-1.3.8-8pleVQgICEo36BRunaYlKV
    data-default-0.7.1.2-86VyjkfSCk63mGj7Z05i2D
    resourcet-1.2.6-60kBeMKLYLU7DGwHkUvFW1 text-2.0.2
    transformers-0.5.6.2 xml-conduit-1.9.1.4-JPqIZb5YtCb7wZw2CS17MS

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
